@@ -1,20 +1,18 @@
-import os
+from .babel.views import LocaleView
+from .security.manager import SecurityManager
+from .security.views import AuthDBView, AuthOIDView, ResetMyPasswordView, \
+    ResetPasswordView, UserDBGeneralView, UserOIDGeneralView, RoleGeneralView, \
+    PermissionViewGeneralView, ViewMenuGeneralView, PermissionGeneralView
+    
+from .views import IndexView
+from filters import TemplateFilters
 from flask import Blueprint
-from flask.ext.babel import lazy_gettext
-from flask.ext.babel import gettext as _gettext
+from flask.ext.babel import Babel, gettext as _gettext, lazy_gettext
 from flask.ext.login import LoginManager
 from flask.ext.openid import OpenID
-from flask.ext.babel import Babel
-
-from .security.views import (AuthDBView, AuthOIDView, ResetMyPasswordView, ResetPasswordView, 
-                        UserDBGeneralView, UserOIDGeneralView, RoleGeneralView, PermissionViewGeneralView, 
-                        ViewMenuGeneralView, PermissionGeneralView, PermissionView)
-from .security.models import User, Role
-from .security.manager import SecurityManager
-from .views import IndexView
-from .babel.views import LocaleView
 from menu import Menu
-from filters import TemplateFilters
+import os
+
 
 
 
@@ -24,7 +22,18 @@ AUTH_LDAP = 2
 
 
 class BaseApp():
-
+    """
+        This is the base class for the all framework.
+        Will hold your flask app object, all your views, and security classes.
+        
+        initialize your application like this::
+            
+            app = Flask(__name__)
+            app.config.from_object('config')
+            db = SQLAlchemy(app)
+            baseapp = BaseApp(app, db)
+        
+    """
     lst_baseview = []
     app = None
     db = None
@@ -76,7 +85,7 @@ class BaseApp():
         lm.init_app(app)
         lm.login_view = 'login'
         oid = OpenID(app)
-
+        
         self.sm = SecurityManager(db.session, 
                             self._get_auth_type(), 
                             self._get_role_admin(), 
@@ -173,7 +182,10 @@ class BaseApp():
             baseview_class.datamodel.session = self.db.session
         return baseview_class()
     
+    
+    
     def add_view(self, baseview, name, href = "", icon = "", category = ""):
+        
         print "Registering:", category,".", name
         if baseview not in self.lst_baseview:
             baseview.baseapp = self
